#
# spec file for package bookworm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.babluboy.bookworm
Name:           bookworm
Version:        1.1.2
Release:        3.1
Summary:        E-book reader
License:        GPL-3.0-or-later
URL:            https://github.com/babluboy/bookworm
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  html2text
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  poppler-tools
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(granite) >= 0.5
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(sqlite3) >= 3.5.9
BuildRequires:  pkgconfig(webkit2gtk-4.0) >= 2.16.0
Recommends:     unrar
Recommends:     unzip

%description
An eBook reader for the Pantheon Desktop.

It uses poppler for decoding and read formats like EPUB, PDF, mobi, cbr, etc.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%find_lang %{appid}
%fdupes %{buildroot}

# fix shebangs
%python2_fix_shebang_path %{buildroot}%{_datadir}/%{appid}/scripts/mobi_lib/*.py
sed -i '1 i #!/usr/bin/sh' %{buildroot}%{_datadir}/%{appid}/scripts/tasks/%{appid}.dictionary.sh

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/%{appid}
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Sun Nov 17 2024 Richard Rahl <rrahl0@opensuse.org>
- update spec file for Leap 16.0:
  * remove mention of elementary
  * remove %%suse_update_desktop_file
  * use autosetup
  * remove a lot of the workarounds, as they are not needed anymore
  * remove recommending lang package
* Thu Oct  7 2021 Matej Cepl <mcepl@suse.com>
- Remove dependency on Python 2
* Mon Aug 12 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.2:
  * Added FB2 mimetype for Files contract - Issue #215
  * Fix for opening last read book and also open the context menu
    for word meaning and annotations only if a selection is made
  * Merge branch 'origin/master' into Weblate.
  * Merge pull request #266 from comradekingu/patch-5
  * Spelling: MIME → media type, full screen → fullscreen
  * Added support for .fb2.zip (Issue #215)
  * Updated support for FB2, FB2 image extraction done (Issue
    [#215])
  * re-added pl.po
  * Updating pl.po
  * Changes for extracting images from FB2 files(Issue #215)
  * Initial imlementation of the FB2 format
  * Updated debian control with granite version 0.5 (Issue #253)
  * Fixed library button status ahead of the user action (Issue
    [#263])
  * Fixed the blank library page issue when the number of books
    is a multiple of the library size (issue #263
  * Fix for pagination boundary conditions - last page skiped
    (Issue #232)
  * Added search, keyboard shortcuts and preference items for
    pagination of library
  * Added search for paginated library (Issue #232)
  * Initial changes for library pagination (Issue #232)
  * Fix for #257
- Switch to meson
- Add HiDPI icons
- Spec file cleanup
* Tue Oct 16 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.1:
  * Updated version for libwebkit2gtk-4.0
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * Updated for Appcenter Juno release
  * Fixed CSS causing overlapping text (Issue #210)
  * Updated CSS to work for both Loki and Juno
  * Removed stateful from SimpleAction on context menu (Issue
    [#203])
  * Added functionality for dictionary word lookup (Issue #185)
  * Fix to prevent external links to be loaded on Bookworm (Issue
    [#180])
  * Changes to add icons/files to GResource (Issue #81)
  * Added html2text to ReadMe for build instructions
  * Merge pull request #204 from fabianfreyer/master
  * Install scripts with group permissions
  * Changes to add highlight colour to prefferences menu (Issue
    [#202])
  * Merge branch 'origin/master' into Weblate
  * Update desktop entry to use standardised Keywords key.
  * Fix spelling of 'successfully'.
- Remove obsolete macros
- Spec file cleanup
* Fri Feb 16 2018 avvissu@yandex.by
- Update to 1.0.0:
  * Updated snapcraft.yaml to fix DBUS issue
  * Updated snapcraft to old data
  * Update snapcraft.yaml
  * Updated snapcraft for granite0.5
  * changing icon path to data directory
  * Added snapcraft badge
  * Updated snapcraft for snap release
  * Fixes for loading a book from right click in Files
  * Fixed the issue of cover image being stretched (Issue #19)
  * Adjusted scrollbar on the reading view to expand for easier
    mouse grabing (Issue #175)
  * Merge branch 'loki' of https://github.com/babluboy/bookworm
  * Fix for table of contents not using anchors correctly (Isse
    [#154])
  * Added branding color (Issue #174)
  * Used libxml for xml parsing for ePubs (Issue #169)
  * Update README.md
  * Added Paypal Badge
  * Typo: “comma seperated” → comma-separated
  * Fixed xml parsing issue for ToC with namespace (Issue #160)
  * Updating travis to have trusty as the distribution
  * Fixed the issue of long titles not wrapping on the default
    cover (Issue #167)
  * Moved default covers out of 256x256 folder
  * Merge branch 'master' of https://github.com/babluboy/bookworm
* Sun Dec 24 2017 avvissu@yandex.by
- Update to 0.9.9:
  * Updated binary in appdata.xml to the RDNN executable name
  * Replaced icon files with RDNN (#157)
  * Updated RDNN executable change in contract and desktop files
  * Fixed RDNN issues for desktop icon (#158)
  * Renamed binary to match RDNN (#157)
  * Fixed an issue of bookworm hanging if the watched folder is
    not set
  * Fixed the issue of covers getting different numbers when
    moving from 0.9.2 to 0.9.5
  * Improvements for Search and Annotation Highlighting
  * Replaced nb.po with nb_NO.po and removed no.po
  * Altered the design to discover books (Issue #104)
* Tue Dec 19 2017 jengelh@inai.de
- Use improved find call execution.
- Ensure neutrality of description.
* Mon Dec  4 2017 avvissu@yandex.by
- Add macros: icon_theme_cache_post{un}, desktop_database_post{un},
  glib2_gsettings_schema_post{un}
* Wed Nov  8 2017 avvissu@yandex.by
- Initial package
